@@ -89,22 +89,19 @@ class PymataExpress:
                         ip port of the device.
         """
         # check to make sure that Python interpreter is version 3.7 or greater
-        python_version = sys.version_info
+        python_version = sys.version_info[:3]
         if sys.platform == 'win32':
-            if python_version[0] > 3:
-                if python_version[1] >= 8:
-                    if python_version[2] >= 3:
-                        pass
-                    else:
-                        raise RuntimeError("ERROR: Python 3.8.2 or greater is "
-                                           "required for use of this program on Windows.")
+            min_version = (3, 8, 2)
+        else:
+            min_version = (3, 7, 0)
 
-        elif python_version[0] >= 3:
-            if python_version[1] >= 7:
-                pass
-            else:
-                raise RuntimeError("ERROR: Python 3.7 or greater is "
-                                   "required for use of this program.")
+        for (v, mv) in zip(python_version, min_version):
+            if v > mv:  # check if version is strictly greater (major first)
+                break
+        else:  # still need to check whether there is not exact equality
+            if not list(python_version) == list(min_version):
+                raise RuntimeError("ERROR: Python {} or greater is "
+                                           "required for use of this program".format('.'.join([str(x) for x in min_version])))
 
         # save input parameters
         self.com_port = com_port
@@ -1527,6 +1524,7 @@ class PymataExpress:
         :param data: message data
 
         """
+        pin_type = PrivateConstants.ANALOG
         pin = data[0]
         value = (data[PrivateConstants.MSB] << 7) + data[PrivateConstants.LSB]
 
@@ -1538,7 +1536,7 @@ class PymataExpress:
             self.analog_pins[pin].event_time = time_stamp
 
             # append pin number, pin value, and pin type to return value and return as a list
-            message = [PrivateConstants.ANALOG, pin, value, time_stamp]
+            message = [pin_type, pin, value, time_stamp]
 
             if self.analog_pins[pin].cb:
                 # if self.analog_pins[pin].cb_type:
@@ -1639,10 +1637,9 @@ class PymataExpress:
             # if self.legacy_mode:
             #     message = [pin, value, PrivateConstants.INPUT, time_stamp]
             # else:
-            if self.digital_pins[pin].pull_up:
-                message = [PrivateConstants.PULLUP, pin, value, time_stamp]
-            else:
-                message = [PrivateConstants.INPUT, pin, value, time_stamp]
+            pin_type = PrivateConstants.PULLUP if self.digital_pins[pin].pull_up else PrivateConstants.INPUT
+
+            message = [pin_type, pin, value, time_stamp]
 
             if last_value != value:
                 if self.digital_pins[pin].cb:
